@@ -26,7 +26,7 @@ import os
 import platform
 import subprocess
 from .exceptions import CegExceptions
-from typing import List, Tuple, Dict, Callable, Union, Optional, Type, TypeAlias
+from typing import List, Dict, Callable, Union, Optional, Type, TypeAlias
 
 __all__ = ("UtilInfo", "Misc")
 
@@ -57,7 +57,9 @@ sub-arguments:
 
 For more usage help, check out https://www.github.com/justaus3r/ceg/#examples"""
     DESCRIPTION: str = "A simple gist crud utility."
-    VERSION: str = "0.1.1"
+    # Caution(message to myself): Be careful when updating the version because
+    # wrong updates can be a mess.
+    VERSION: str = "0.2.0"
 
 
 def exception_executioner(exception_obj) -> None:
